"""Enable python -m netlint."""
from netlint.cli.main import cli


if __name__ == "__main__":
    cli()
